@@ -5,7 +5,7 @@ from zope.schema               import TextLine
 from zope.schema.fieldproperty import FieldProperty
 
 ALPHA = re.compile('^[a-zA-Z0-9_\-\.,\s]+$')
-ADDR  = re.compile('^[a-zA-Z0-9_\-\#\.,\s]+$')
+ADDR  = re.compile('^[a-zA-Z0-9_\-\#\.\/,\s]+$')
 
 class IAddress(Interface):
     """Defines an interface for address types."""
